@@ -10,8 +10,7 @@ sub new
 {
     my $class = shift;
     $class->SUPER::new ( -text  => 'Invalid command name',
-			 -value => 500,
-	                 -object=> shift );
+			 -value => 500 );
 }
 
 1;
