@@ -43,8 +43,12 @@ sub setEntity
 {
     my ( $this, $entity ) = @_;
     my $ref = ref ( $entity ) || throw Net::RRP::Exception::InvalidEntityValue;
-    { 'Net::RRP::Entity::Domain' => 1, 'Net::RRP::Entity::NameServer' => 1  }->{ $ref } ||
-	throw Net::RRP::Exception::InvalidEntityValue();
+    {  'Net::RRP::Entity::Domain'     => 1,
+       'Net::RRP::Entity::NameServer' => 1,
+       'Net::RRP::Entity::Registrar'  => 1,
+       'Net::RRP::Entity::Replica'    => 1,
+       'Net::RRP::Entity::Owner'      => 1,
+       'Net::RRP::Entity::Contact'    => 1 }->{ $ref } || throw Net::RRP::Exception::InvalidEntityValue ();
     $this->SUPER::setEntity ( $entity );
 }
 
@@ -59,6 +63,18 @@ sub setOption
     throw Net::RRP::Exception::InvalidCommandOption ();
 }
 
+=head2 isSuccessResponse
+
+Command: CHECK Success: 210, 211, 212, 213
+
+=cut
+
+sub isSuccessResponse
+{
+    my ( $this, $response ) = @_;
+    return { 210 => 1, 211 => 1, 212 => 1, 213 => 1 }->{ $response->getCode() };
+}
+
 =head1 AUTHOR AND COPYRIGHT
 
  Net::RRP::Request::Check (C) Michael Kulakov, Zenon N.S.P. 2000
