@@ -2,6 +2,9 @@ package Net::RRP::Request::Quit;
 
 use strict;
 use Net::RRP::Request;
+use Net::RRP::Exception::InvalidCommandOption;
+use Net::RRP::Exception::InvalidEntityValue;
+
 @Net::RRP::Request::Quit::ISA = qw(Net::RRP::Request);
 $Net::RRP::Request::Quit::VERSION = '0.1';
 
@@ -30,24 +33,24 @@ sub getName { 'Quit' };
 
 =head2 setEntity
 
-say "die" immediate
+throw Net::RRP::Exception::InvalidEntityValue immediate
 
 =cut
 
 sub setEntity
 {
-    die "you can't setup entity for quit request";
+    throw Net::RRP::Exception::InvalidEntityValue ();
 }
 
 =head2 setOption
 
-say "die" immediate
+throw Net::RRP::Exception::InvalidCommandOption () immediate
 
 =cut
 
 sub setOption
 {
-    die "you can't setup any option for quit request";
+    throw Net::RRP::Exception::InvalidCommandOption ();
 }
 
 =head2 isSuccessResponse
@@ -79,7 +82,9 @@ sub isSuccessResponse
 
 =head1 SEE ALSO
 
-L<Net::RRP::Request(3)>, L<Net::RRP::Codec(3)>, RFC 2832
+L<Net::RRP::Request(3)>, L<Net::RRP::Codec(3)>, RFC 2832,
+L<Net::RRP::Exception::InvalidCommandOption(3)>,
+L<Net::RRP::Exception::InvalidEntityValue(3)>
 
 =cut
 
